# tests for autocompletion
impo	sys
not_exist.	
not_exist	
x = '123'
1, x.isdi	()
i = str
i.lowe	('ABC')
None.	
